@@ -10,19 +10,22 @@ class OnlineDocsView(TemplateView):
     """View that displays the docs for the current URL path."""
     def dispatch(self, request, *args, **kwargs):
         self.path = request.GET.get('path')
-        if not self.path:
+        self.file = request.GET.get('file')
+        if not self.path and not self.file:
             raise Http404
         return super(OnlineDocsView, self).dispatch(request, *args, **kwargs)
 
     def get_context_data(self, **kwargs):
         ctx = super(OnlineDocsView, self).get_context_data(**kwargs)
         document_name = self.get_document_name()
+
         try:
             template = loader.get_template('online_docs/' + document_name)
             template_ctx = RequestContext(self.request)
             template_rendered = template.render(template_ctx)
         except TemplateDoesNotExist:
             template_rendered = None
+
         ctx.update({
             'docs': template_rendered,
             'document_name': document_name,
@@ -31,6 +34,8 @@ class OnlineDocsView(TemplateView):
         return ctx
 
     def get_document_name(self):
+        if self.file:
+            return self.file
         url = resolve(self.path)
         document_name = '%s.md' % url.view_name.replace(':', '_')
         return document_name
